@@ -14,7 +14,7 @@ def bindq_options(args):
                        action="store",
                        default="",
                        metavar="KEY",
-                       help="the routing key to use when binding the queue to its exchange (default: unset)")
+                       help="the routing key to use when binding the queue from its exchange (default: unset)")
     add_connection_options(options)
     return options.parse_args(args)
 
